Handbook - Alimentary System Pharynx
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

GIF Container

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

ALIMENTARY SYSTEM PHARYNX Click pictures for new window with figure and legend, click again for high resolution image
1 Overview C. elegans feeds on bacteria in liquid suspension. Bacteria taken in by the mouth are concentrated, ground and transported to the intestine by a tube-like muscular pump called the pharynx. The pharynx is an epithelial organ that has its own muscles, nervous system, gland cells and structural cells. It contains 9 epithelial cells, 20 muscle cells, 9 marginal cells, 4 gland cells and 20 neurons (PhaFIG 1), and 6 valve cells at its posterior (see also PharynxAtlas). It is about 100 µm long and has a diameter of approximately 20 µm at its widest (at the posterior bulb). At the anterior, it is connected to the buccal cavity and at the posterior, to the intestine. The pharynx is isolated from the rest of the animal by a specialized basal lamina that lines the basal surface of the pharyngeal cells and isolates the pharynx from the pseudocoelom. There may be hormonal signaling between this organ and the rest of the body by way of the pseudocoelomic fluid. The apical surface of the pharyngeal cells lies medially towards the lumen, which is lined with a cuticle secreted by the pharyngeal muscle and marginal cells. At several locations pharyngeal cuticle takes the form of specialized structures, such as the anterior “flaps”, the “sieve” and the “grinder” (PhaFIG 2; see Cuticle) (Avery and and Thomas, 1997). PhaFIG 1: Pharyngeal cell nuclei. (Based on drawing by Ron Ellis.) (Red) Neuron nuclei; (green) pharyngeal muscle nuclei; (lavender) gland nuclei; (fuchsia) marginal cell nuclei; (purple) epithelial nuclei. A. Graphic rendition; left lateral view of the ventral, left-side and dorsal nuclei. B. Graphic rendition; left lateral view of the right-side nuclei. Note: g1AL and pm5VL on the left side and g1AR and pm5VR on the right side were switched in previous versions of this figure. This is a corrected image (pers. comm. L. Avery). PhaFIG 2: Pharynx anatomy. A. Graphic rendition of the pharynx. The metacorpus is also called the anterior bulb, the median bulb, or the first bulb. The posterior bulb is also called the terminal bulb or the second bulb. At the anterior end, the pharynx is connected to the buccal cavity. At the posterior end, it is connected to the intestine through the pharyngeal-intestinal valve (vpi). B-F. TEM sections through various parts of the pharyngeal lumen. Section levels are indicated in G. B. Buccal cavity at the level of the pharyngeal epithelial cells. (Image source: N2T [MRC] A60-24, print 062.) C. Procorpus. The channels (arrows) are seen at the three corners of the lumen. (Image source: N2W [MRC] A386-2.) D. Metacorpus at the level of the two ventral gland (Gl) openings and M3 cell bodies. Bacteria (arrows) are seen in channels and the lumen contains a filamentous sieve structure. (Image source: [MRC] JSA-107.) E. Posterior of the isthmus at the level of the excretory duct. (Image source: N2S [MRC] A1-4.) F. Grinder in the terminal bulb. (Image source: N2U [MRC] print 401.) G. DIC micrograph of the pharynx. The pharynx has a distinctive shape; an extended anterior portion (procorpus) is connected to the buccal cavity via the pharyngeal epithelium (Albertson and Thomson, 1976; Franks et al., 2006). The metacorpus, also called the first bulb, lies posterior to the procorpus. The procorpus and metacorpus together make the corpus of the pharynx. Between the corpus and the second bulb (also called the terminal bulb) lies the isthmus (PhaFIG 2). The large somatic nerve ring surrounds the isthmus on the outside. The pharynx has intrinsic myogenic activity that is regulated by its nervous system. When the entire pharyngeal nervous system is ablated, the pharynx continues to pump, albeit in a slow and uncoordinated manner (Avery and Horvitz, 1989). The nervous system, in turn, integrates internal signals such as the animal’s nutritional status and external signals such as the presence or absence of food (Avery and Horvitz, 1989; Franks et al., 2006). In the absence of food, the pharynx pumps approximately once every second, whereas in the presence of food the rate increases to about four pumps per second. Starved and well-fed worms show initially different pumping rates upon transfer from solid to liquid media (Avery et al., 1993; McCloskey et al., 2017). The pumping rate of the pharynx is also modulated by the somatic sensory system; for example, pumping is briefly inhibited upon sensing a light touch to the body (Chalfie et al., 1985; Avery and Thomas., 1997).
2 Embryonic Development of the Pharynx Unlike the intestinal cells, all of which arise from a single founder cell E, the pharynx is composed of cells that arise from both AB and MS founder cells (AlimFIG 1). In these lineages, no strict clonal and lineal derivation can be recognized, and there is a heterogeneity of ancestry with respect to the final cell fate (PhaMOVIE 1&2). In the anterior divisions, no lineal boundaries exist between hypodermal, arcade and pharyngeal daughters. The pharyngeal components derived from MS and AB do not possess any functional boundaries either, such that in pm3, pm4 and pm5 muscle groups identical cells arise from these two lineages and some MS descendants fuse with those coming from the AB blast cell (Sulston et al., 1983; Horner et al., 1998). During gastrulation, at approximately the 100-cell stage and after the movement of gut precursors to inside of the embryo, MS descendants start to move inward through the blastopore (AlimFIG 1 and PhaFIG 3A-D) (Bucher and Seydoux, 1994; Mango, 2007). Slightly later, AB-derived precursors of the pharynx move inside of the embryo. At 150-260 minutes, pharyngeal precursor cells arrange in a bilateral “double plate” organization (Rasmussen et al., 2013). This is followed at 330-390 minutes by nuclear movement and constriction of cell’s apical boundaries at the double plate midline leading to the formation of a compact “cyst” pharyngeal primordium (Rasmussen et al., 2008; Rasmussen et al., 2013). These cells are attached to each other and to the midgut by adherens junctions. However, they are not yet attached to the buccal cavity (see Epithelial System - Hypodermis) (Portereiko and Mango, 2001). At this time, 78 of the 80 pharyngeal cells are already born. During the next hour, pharyngeal extension occurs such that the pharyngeal precursors reposition themselves to form a central cylinder and link to the buccal cavity, whereas the body myoblasts position themselves between this cylinder and the outer layer of cells. Pharyngeal extension is accomplished in roughly three steps: reorientation, epithelization and contraction (see Epithelial System - Hypodermis) (Portereiko and Mango, 2001). Later, the pharyngeal tube morphs into a bilobed structure and develops a lumen. Lumen formation is thought to be performed by retraction of the tips of the marginal cells from the midline of the pharyngeal primordium when the pharyngeal muscles differentiate and contract (PhaFIG 3E-G) (Leung et al., 1999). An exception to this is the pm8 and vpi1 cells at the posterior end of the pharynx, which form adjacent single cell tubes through detachment from the basal lamina, lamellar invasion, and self-fusion. vpi1 forms a toroidal tube during embryogenesis that connects with itself through self-fusion (Rasmussen et al., 2008). Cell fusions in the pharynx occur either before or soon after hatching (Sulston et al., 1983). C. elegans initiates pharyngeal pumping right before hatching.
1A |  | 1B |  |
2 |  |
PhaMOVIE 1A&B and PhaMOVIE 2: Development of a 3-D pharynx. 0 min is first cleavage, which is approximately at 40 min after fertilization. 1A&B (top row). Pharynx is derived from AB and MS lineages. (Blue spheres) Cells from AB lineage; (green spheres) cells from MS lineage; (pink spheres) cells from E lineage that form the intestine. A, ventral view; B, left side view. 2 (bottom row). After a bilayer of pharynx primordium forms, cells from both AB and MS lineages wedge themselves between this bilayer to create a 3-D pharynx. (Dark green spheres) Left sheet of the bilateral pharynx primordium; (light green spheres) right sheet of the bilateral pharynx primordium; (yellow spheres) cells that create the third layer of the pharynx primordium as the first step to create a 3-D pharynx. Colors do not follow the WormAtlas color code. Click arrows to play the movies and on the movies to go to the lineage key page with larger movies and precursor and lineage keys (Movie source: A. Santella and Z. Bao.) PhaFIG 3A-D: Embryonic development of the digestive tract. (Based on Sulston et al., 1983 and Leung et al., 1999.) A. 200 minutes after first cell cleavage (99-cell stage), ventral aspect. (Dark green) Cells from MS lineage; (light green) cells from AB lineage. B. 260 min after first cell cleavage (late gastrulation), ventral aspect. (Green arrow) Blastopore in which cells migrate inside the embryo. C. End of gastrulation, dorsal aspect, midplane. Pharynx (Ph) and intestine (Int) after tubular extension. D. 430 min after first cell cleavage, lateral aspect. Pharynx and intestine are separated from the surrounding tissues by a basement membrane. Epithelization of the buccal cavity is complete. PhaFIG 3E-G: Embryonic development of the digestive tract. E. Development of the pharyngeal lumen by retraction of the marginal cells from the midline when pharyngeal muscles begin to contract. (Left panel) A 400-minute embryo; (middle panel) 430-minute embryo; (right panel) late embryogenesis. (aj) Adherens junctions. F. Adherens junctions between muscle and marginal cells (black arrows) and adherens junction remnants (white arrows) within the syncytial muscle cells. (Ch) Pharyngeal channels. TEM, transverse section. Bar, 1 μm. G. Adherens junction remnant (arrow) immunogold-stained with gold-coated MH-27 antibody. (Image source: Hall archive.)
3 Pharyngeal (Buccal) Epithelium A series of interfacial cells join the lips to the buccal cavity and the buccal cavity to the pharynx (See Epithelial System - Interfacial Epithelial Cells; PhaFIG 4A-D; PharynxAtlas) (Wright and Thomson, 1981). The buccal cavity is surrounded, from anterior to the posterior, by the anterior hypodermis and the arcade cells, which constitute the anterior limit of the pharyngeal lumen (PhaFIG 4E-I; InterFIG 1; InterFIG 3). Each of these cells contributes small territories along the buccal cavity and their cell bodies lie more posteriorly in the head. The arcade cells are contiguous with the pharyngeal epithelium, a thin tube made from nine cells, formed by two successive rings of nonsyncytial tissue with sixfold symmetry (PhaFIG 5) (Albertson and Thomson, 1976). Similar to the anterior hypodermal cells and the arcade cells, the cell bodies of the epithelial cells lie far posterior to the buccal cavity and extend thin processes anteriorly within the pharyngeal nerve cords to reach their territories surrounding the lumen (Albertson and Thomson, 1976). The most anterior epithelial cells, e1, are positioned as a single dorsal and two subventral cells, covering markedly thinner territories (as measured along the a/p axis) than the other six cells. The posteriormost cells, e3, are positioned in the same pattern, and their epithelial territories lie directly behind those of e1 cells. The intervening e2 cells lie at the three apices of the triangular lumen, and their epithelial territories span the width of both the e1 and e3 cells, yielding a sixfold symmetry. At their lateral borders, all of these epithelial cells are firmly connected to their immediate neighbors by large adherens junctions (running continuously at the apical border). Where the epithelial cells border the posterior arcade cells, there are again very prominent adherens junctions (PhaFIG5 D&E). PhaFIG 4A-D: The anterior digestive tract is formed by the alignment of a series of cells. A&B. Sarcomeres of pm1 lie near the posterior edge of the buccal cavity. A. Epifluorescent image of pm1 in an animal expressing a GFP-tagged transgene. (NR) Nerve ring. (Strain source: Z-W. Wang and B. Chen.) Magnification 400x. B. Same animal in merged DIC and epifluorescent images. C&D. Anterior to pm1, pharyngeal epithelium surrounds the posterior buccal cavity. C. Epifluorescent image of the pharyngeal epithelium and pm3 in an animal expressing a GFP-tagged transgene. (Strain source: Z-W. Wang and B. Chen.) Magnification, 600x. D. Same animal in merged DIC and epifluorescent images. PhaFIG 4E-I: The anterior digestive tract is formed by the alignment of a series of cells. E&F. The thin ring of the syncytial hyp 1 cell surrounds the anterior buccal cavity in an adult (see Epithelial System - Hypodermis). E. Epifluorescent image of hyp 1 in an animal expressing a GFP-tagged transgene. Inset shows hyp1 in a larval animal from the same strain. (Strain source: Z-W. Wang and B. Chen.) Original magnification, 400x. F. Same animal in merged DIC and epifluorescent images. G. Two consecutive rings of arcade cells, anterior and posterior, lie just behind hyp1 and anterior to pharyngeal epithelium along the buccal cavity. Epifluorescent images taken from an animal expressing a GFP-tagged transgene. (Strain source: Z-W. Wang and B. Chen.) Magnification, 600x. H. Same image as in G, magnified. I. Graphic rendition of the structure of the anterior alimentary canal. The processes of hyp1 and arcade cells extend along the pharynx to reach the buccal region. Pharyngeal tissues (pharyngeal epithelium and pharyngeal muscles) begin posterior to the arcade rings. PhaFIG 5A-C: Pharyngeal epithelium. All except insets are transverse section TEM images. A. Ring of nine epithelial cells encircle the anterior of the pharynx. The dorsal and subventral sides of this circle are occupied by the e1 cells. Three e2 cells are localized at the corners of the lumen. Their thin processes make a short clockwise turn in front of pm1 to connect to the buccal cavity portion. Posterior to e1, three e3 cells occupy the dorsal and subventral regions of the posterior buccal cavity. The cell bodies of e1, e2 and e3 are located, respectively, about 30, 20 and 35 μm posteriorly within the corresponding nerve cords. (Based on Albertson and Thomson, 1976.) (Inset) DIC image indicating the levels of B and C. B. Transition between the posterior arcade cells and the pharyngeal epithelium. The cells are connected to each other by large adherens junctions (arrow), sealing the pharynx to the buccal tissues. Numbers seen in B and in C-E are from the original prints. Bar, 1 μm. (Image source: N2T [MRC] A60-8.) C. Relationship of e1 and e2 cells at the anterior of the pharyngeal epithelium. Cells within each set do not touch to each other, but e1 and e2 cells are connected to each other by adherens junctions (arrows). (Image source: N2T [MRC] A60-22.) PhaFIG 5D&E: Pharyngeal epithelium. D. Level slightly posterior to C. e2 and e3 cells are connected to each other by adherens junctions (white arrowheads). (Top inset) Section level. Intermediate filaments (arrows), which extend from the lumenal cuticle to the pharyngeal basal lamina, are attached to the basal lamina by electron-dense half-desmosomes (arrowheads). Bar, 1 μm. (Image source: N2T [MRC] A61-11.) E. Posterior of the pharyngeal epithelium and the anterior of the pharyngeal musculature. Three cuticular flaps are also seen. (Image source: N2T [MRC] A63-4.) The pharyngeal epithelium is a rather rigid narrow cylinder that restricts entry of food into the pharynx. Its cylindrical shape is heavily reinforced by short radial bundles of intermediate filaments anchored to the apical and basal membranes of the epithelial cells by large hemidesmosomes. These well-anchored filaments seem to limit the epithelial cylinder from stretching or collapsing, despite the vigorous movements of the nearby pharyngeal musculature. The pharyngeal epithelial cells also secrete the cuticle that lines the buccal cavity along the former mesostom portion. The inside caliber of the buccal epithelial lumen increases markedly at each larval molt, and this increase in size of the buccal cavity is suggested to permit increased growth rate after each molt (Knight et al., 2002). The buccal cavity is much narrower in the dauer larva, which stops actively feeding (DCutFIG4).
4 Muscle Cells of the Pharynx The pharyngeal muscles are grouped into eight separate segments (pm1-pm8), which are arranged as eight consecutive rings encircling the pharynx (PhaFIG 6A-C; PharynxAtlas) (Albertson and Thomson 1976; Avery and Thomas, 1997; Franks et al., 2006). Unlike the body wall muscles, no hypodermal layer separates the muscle anchorage from the cuticle lining the lumen of the pharynx. Indeed, most of the pharyngeal muscles appear to participate directly in secreting cuticle (e.g., the two anteriormost pharyngeal muscle cells, pm1 and pm2, secrete the cuticle that lines the metostom and telostom portions of the buccal cavity) and thus qualify as having myoepithelial properties (Albertson and Thomson 1976, D.H. Hall, unpublished). Consistent with this, the pm1 cells are required for secretion of the metastomal flaps (Sando et al., 2021). Most of the pharyngeal muscle segments are made up of three syncytial cells positioned in a three-fold symmetrical manner in any cross section (PhaFIG 6D). Each of these cells contains two nuclei as a result of fusion of two cells around the time of hatching (See Table 1 in Albertson and Thomson 1976; see also PhaTABLE 1). In pm2-pm5 of adult pharynx, there are still small remnant adherens junctions at the sites of former cell fusions between pairs of muscle cells, marking the exact apical border where the fusion has occurred (PhaFIG 3) (Hedgecock and Thomson, 1982). These remnant junctions express the AJM-1 protein and can be stained by immunocytochemistry (Koppen et al., 2001; D.H. Hall, unpublished). The three muscle cells of each segment are separated from each other by three marginal cells, whereas the muscle cells of the neighboring rings are linked by gap junctions and also connected via interlocking short fingers on the anterior and posterior margins. Each syncytial muscle cell contains a deep groove on the basal side where a longitudinal pharyngeal "nerve cord" is situated (PhaFIG 6 and PhaFIG 7A). These nerve cords enclose the cell bodies and processes of neurons, gland cells, and anterior epithelial cells. Many synapses, including neuromuscular junctions onto the pharyngeal muscles, occur along these cords. PhaTABLE 1: Characteristics of pharyngeal muscle cells and marginal cells. As a general rule, cells also have gap junctions with their nearest neighbors (marginal cell to muscle cell within a segment, marginal cell to marginal cell, and muscle cell to muscle cell between segments). apm4 and pm5 were originally described as a set of three binucleate syncytia (Albertson and Thomson 1976). Reanalysis by Harry et al., (2022) of original MRC micrographs has shown that both are single syncytia with six nuclei each. bSynaptic input for Albertson and Thomson (1976) did not distinguish between bilaterally symmetrical cells. cCook et al., (2019) conducted a reanalysis of the original MRC micrographs and uncovered previously unknown connections. dBhatla et al., (2015) restricted their analysis to a subset of connections. eLeon Avery, pers. comm. PhaFIG 6A-C: Muscle cells of the pharynx. A. There are eight muscle segments (pm1-pm8) in the pharynx. All but pm6, pm7 and pm8 form syncytia. The most anterior segment, pm1, is a single cell with six nuclei. Its processes extend anteriorly adjacent to the anterior edges of the marginal cells and terminate in a ring structure. Each pm2 soma has two nuclei and projects into a nerve ring to extend anteriorly. pm3 cells are located in the procorpus, pm4 in the anterior bulb, and pm5 in the isthmus. pm4 and pm5 are single syncytia forming bridges (asterisk) between each trilateral sector Harry et al (2022) (see PhaFIG 7A). The terminal bulb contains pm6-pm8. The last muscle segment contains a single cell, pm8, that has a single nucleus located on the left side. (Top insets) Epifluorescence images of pm1 (left), pm6 (middle), and pm8 (right) in animals expressing GFP-tagged transgenes. (Strain source: Z-W. Wang and B. Chen.) Each magnification, 400x. B. Pharyngeal muscle cells contain radially oriented filaments. Here, myofilaments in pm3-pm7 can be seen in an epifluorescence image taken from a transgenic animal expressing the reporter gene, C32F10.8::GFP. (Asterisk) Position of g1 gland cells. (Image source: R. Newbury.) C. Muscles of the terminal bulb. Epifluorescence image from a transgenic animal expressing the reporter gene, K02A4.1::GFP. (Image source: R. Newbury.) Pharynx 3D is an interactive viewer that allows the user to explore the anatomy of the pharynx in detail by manipulating the pharyngeal structures in three dimensions. Menu options allow for toggling between different views. PhaFIG 6D: Muscle cells of the pharynx. The pm4 and pm5 cells are single syncytia with six nuclei total formed through fusion at restricted locations of the otherwise spatially separated trilateral sectors (Harry et al., 2022). (Image source: N2T [MRC] print# 741, 742, 744, 746). Pharynx 3D is an interactive viewer that allows the user to explore the anatomy of the pharynx in detail by manipulating the pharyngeal structures in three dimensions. Menu options allow for toggling between different views. Specialized zones mark the apical regions of several of the pharyngeal muscles where they secrete cuticle. Here, the cytoplasm contains electron dense tubules, and sometimes, dense core vesicles just under the plasma membrane. The cytoplasm of pm6 is particularly specialized in the region underlying the grinder, which is a very elaborate cuticular structure secreted by the pm6 muscle cells (PhaFIG 2). During the lethargus period preceding each larval molt, pm6 and pm7 produce secretory vesicles, which interrupt the sarcomeres. Vesicles with electron dense cores predominate during shedding of the L4 cuticle, while electron lucent core vesicles are dominant during the formation of the adult cuticle (Sparacio et al., 2020). Prominent networks of sarcoplasmic reticulum along the borders of each muscle sarcomere presumably sequester calcium needed for muscle contractility. Pharyngeal muscle cells also contain many mitochondria. In most pharyngeal muscle segments, contractile filaments are oriented radially, and when the muscles contract, the pharyngeal lumen opens. However, in the terminal bulb, the pm7 muscle filaments are oriented obliquely with regard to the anterior-posterior axis and pull on the grinder region when the muscle contracts. pm1-pm4 function in sucking up and trapping bacteria. pm5 regulates flow of food from corpus to the terminal bulb, and pm6-pm8 operate the grinder. 5 Marginal Cells The pharynx is a mosaic of several non-equivalent cell types, each with threefold symmetry that assemble into a nonstratified, one-cell-deep epithelium along the lumen (PhaFIG 7A; PharynxAtlas). As described above, muscle cells are a major part of this epithelium. Cells of another type, the marginal cells (mc), are placed at the three corners of the pharyngeal lumen and separate the muscle cells from one another. There are three mc segments along the pharynx and a total of seven marginal cells; three mc1 cells comprise the anterior segment, three mc2 cells comprise the second segment, and a syncytial mc3 cell with three nuclei comprises the terminal bulb segment (PhaFIG 1 and PhaFIG 6). From segment to segment, the marginal cells lie in rows at the corners of the lumen. They vary markedly in size between segments, but the three cells within one segment are essentially equivalent. Marginal cells supply reinforcing strength to this muscular organ. Their large size and block-like shape is fortified by the placement of large radial bundles of intermediate filaments running from apical to basal borders of each cell. These filaments are anchored to the plasma membrane by large hemidesmosomes. Within each segment, the marginal cells are linked to neighboring muscle cells on their lateral borders by large gap junctions as well as apical adherens junctions separating the membrane to apical and basal surfaces (PhaFIG 7B&C) (Avery and Thomas, 1997). Large interlocking finger-like extensions also connect marginal cells to muscles within each segment and may also add to the structural integrity of the whole organ. Because of this arrangement, marginal cells within a segment communicate with muscle cells of the same segment and not with other marginal cells. In contrast, between segments, these cells form interlocking fingers and gap junctions to neighboring marginal cells. The marginal cells contain many mitochondria, which suggests that these cells may perform some active role beyond merely providing continuity and strength to the epithelium. Because marginal cells are coupled to pharyngeal muscles via gap junctions, they may have some motor function, i.e., they may be myoepithelial in nature. Alternatively, they may act as relay stations to synchronously transmit signals from motor neurons to surrounding pharyngeal muscles so that all pharyngeal muscles within a segment can contract and relax at the same time. It is noteworthy that when the pharyngeal muscles contract, the muscle cells become thinner to open the lumen. Because the marginal cells are already relatively thin, this suggests that at full contraction, the pharyngeal lumen may open practically as wide as the inside corners of the marginal cells and form an open triangular lumen, whereas when the muscles relax, the lumen is practically closed except for the three channels at the apices of the anterior lumen. PhaFIG 7A: Marginal cells of the pharynx. A. Marginal cells lie along the three corners of the pharyngeal lumen. Syncytial pharyngeal muscle cells lie between the marginal cells in the dorsal and subventral positions. Pharyngeal nerve cords, which contain the cell bodies of the epithelial cells, the gland cell processes and the neurons, are situated in grooves within the muscle cells. Cells are pseudocolored on a transverse TEM image. (Inset) Raw TEM image. (Top) Graphic rendition of the section level along the pharynx. PhaFIG 7B&C: Marginal cells of the pharynx. B. Epifluorescence image of marginal cells expressing the reporter gene C07H6.3::GFP. (Image source: R. Newbury.) C. Pharyngeal muscle cells and marginal cells (mc) are connected to one another by adherens junctions (aj) and gap junctions (gj). TEM image. (Image source: Hall archive.) 6 Gland Cells of the Pharynx Two classes of gland cells, g1 (three cells) and g2 (two cells), are found in the second bulb of the pharynx (PhaFIG 8; PhaMOVIE 3; PharynxAtlas). Although previously dorsal g1 and right ventral g1 cells were reported to fuse, results with fluorescent markers suggest that these cells remain separate (Smit et al., 2008). Gland cell morphology is sculpted by surrounding muscle cells (PhaFIG 8H) (Raharjo et al., 2011). The g1 cells extend three cuticle-lined ducts anteriorly within the narrow pharyngeal nerve cords. Two of these ducts pass through the isthmus before emptying into the pharyngeal lumen near the first bulb. The dorsal g1 duct travels much farther and empties near the anterior limit of the pharynx. The g2 cells also extend ducts, which are much shorter and empty into the lumen of the second bulb. The g1 cells contain a lamellar cytoplasm and few vesicles, whereas the g2 cells have a rather clear cytoplasm and more vesicles. These contents may vary from animal to animal, and vesicle sizes are quite large and variable. Gland cells receive motor innervation from M4 and M5 motor neurons, which suggests that they may be stimulated to secrete digestive enzymes synchronously with pharyngeal pumping activity. Periodic episodes of secretion (vesicle motion) have been seen in g1 ducts by light microscopy and are apparently associated with molting (Singh and Sulston, 1978; Hall and Hedgecock, 1991). This suggests that gland secretion may participate in the digestion of the pharyngeal cuticle during molting. PhaFIG 8A-G: Gland cells of the pharynx. There are five gland cells: two posterior subventral g2 cells, one right and one left subventral g1 cells and a dorsal g1 cell. A. Epifluorescence image of gland cells taken expressing the reporter gene B0280.7::GFP, left lateral oblique view. (Image source: R. Newbury.) B. Graphic rendition of gland cells. (Although previously the dorsal and right side g1 cells were reported to fuse at the anterior of the terminal bulb and hence make a syncytium, more recent results suggest they stay separate (Smit et al., 2008). The pair of subventral g1 cells open to the pharyngeal lumen at the posterior of the first bulb, whereas g2 gland cells open into the lumen anterior to the grinder. (Black ovals) Gland cell nuclei; (short arrows) gland openings to lumen. C. The dorsal g1 gland duct lies within the dorsal nerve cord and opens to the lumen through a short cuticular duct (arrow) close to the buccal cavity. Nearby muscles attach to the duct with adherens junctions (white arrowhead). (Image source: [MRC] N2T A64-4, print# 140.) D&E. Epifluorescence images of gland cells expressing the reporter gene F20B10.1::GFP or phat-1::GFP (E, bottom panel). D. Ventral oblique view. (Arrow) Dorsal g1 process. E. Ventral view (both panels). (Arrows) Ventral g1 processes. (Strain source [top panel]: L. Haklai-Topper and E. Peles.) (Image source [bottom panel]: R. Smit and J. Gaudet.) Magnification, 400x. F. The g1 cells have lamellar cytoplasm, whereas the g2 cells have lighter cytoplasm with vesicles. TEM, transverse section through the posterior terminal bulb. (Image source: [MRC] N2W print# 935.) G. Epifluorescence images of dorsal gland cells expressing the reporter gene Y8A9A.2::GFP. (Arrow) dorsal g1 process. (Image source: R. Smit, V. Ghai and J. Gaudet.) PhaFIG 8H: Gland cells of the pharynx. H. Same TEM section as in F, pseudocolored. Top graphic shows the section level along the pharynx. (Inset) Raw TEM image. (Image source: [MRC] N2W Print# 935.) PhaMOVIE 3: 3-D reconstruction of pharyngeal gland cells. 3-D movie was created from confocal images of a strain expressing the GFP marker linked to the promoter for B0280.7 using Zeiss LSM 5 Pascal software v. 3.2. (Image source: R. Newbury and D. Moerman.) Click on image to play movie. 7 Pharyngeal Neurons The pharynx has 20 intrinsic neurons of 14 types, all of which have cell bodies located in the anterior or posterior bulb (see also PharynxAtlas). Six types are bilaterally paired and eight are single neurons. These neurons extend processes anteriorly and/or posteriorly along the three longitudinal pharyngeal nerve cords (the dorsal and the right and left subventral) and form a small plexus (the pharyngeal nerve ring) within the anterior bulb where they decussate to the other side. A half-ring (the terminal bulb commissure) is made by neuronal processes more posteriorly within the anterior portion of the terminal bulb (PhaFIG 9 and PhaFIG 10). A few neurons (M1, M2 and M3) send out processes along unique routes. The M1 process runs anteriorly between the muscle and the right marginal cell until it reaches the pharyngeal nerve ring where it relocates to the dorsal nerve cord and continues traveling anteriorly in this location. Unlike other neuron processes, M2 and M3 processes do not make their dorsal turn within the pharyngeal nerve ring, but more anteriorly within the pm4 where they pierce through the pm4 as they travel towards the dorsal side to enter the dorsal nerve cord (PhaFIG 10E-J). M2 neurons make synapses to pm4 along the way. PhaFIG 9A-E: Pharyngeal neurons. A. Schematic of pharyngeal neurons I1L, NSML and M2L. (Arrowhead) Position of the pharyngeal nerve ring where processes from these and other neurons make dorsal-ventral turns. (Boxes) Section levels of D and E. B. Epifluorescent image of I1L expressing the reporter gene, zag-1::GFP, lateral view. (NR) nerve ring. (Strain source: S. Clark.) Magnifications, 400x. C. Epifluorescent image of NSML expressing the reporter gene tph-1::GFP, lateral view. (NR) nerve ring. Box indicates level of E. (Strain source: S. Clark.) Magnifications, 400x. D. Transverse TEM section where the somatic neuron RIP enters the pharynx to make gap junctions (inset, white arrow) to the pharyngeal neuron I1. The subcuticular ending of I1 is also seen close to the lumen. Bar, 1 μm. (Image source: [MRC] Q series 1730-8a.) E. Subcuticular ending of one NSM cell near the pharyngeal nerve ring. NSM attaches to the muscle cell by adherens junctions (arrowheads). Muscle cells contain dark-staining tubules and make adherens junctions to marginal cells (mc) as well (arrowheads). (Inset) NSM, enlarged, with multiple small clear vesicles inside. (Numbers on the image are from the original print.) (Image source: N2T [MRC] A348-8.) PhaFIG 9F-H: Pharyngeal neurons. F&G. Subventral F and dorsal G NSM processes reach the basal side via short branches containing many vesicles (arrow) and presynaptic densities towards the pseudocoelom. (Numbers on the images are from the original prints.) (Bl) basal lamina. (Image source [MRC] N2W print# 115.) H. Schematic of the I5 and M5 neurons. (Arrowhead) Terminal bulb commissure. PhaFIG 10A&B: Neuronal process trajectories. All panels except A are transverse TEMs. Bars in B-J, 1 μm. (Image source: N2W [MRC] A382-A409, print# 663). A. Schematic illustration of section levels in panels B-J. B. Cell bodies of I4 and M2 neurons in the terminal bulb. PhaFIG 10C-J: The processes of three of the pharyngeal neurons M1, M2 and M3. C. M3 cell bodies are near the ventral g1 duct openings into the lumen. D. Pharyngeal nerve ring is composed of the circumferential neuron processes. E-J. Consecutive sections through the first bulb show the trajectories of M2 and M3 processes piercing pm4 to reach the dorsal cord. (Image source: N2W [MRC] prints C-J 93, 80, 52, 51, 49, 40, 39, 33.) Most of these processes interact synaptically with others within the pharyngeal nerve ring, formed between the narrow region where pm4 and pm5 appose each other (PhaFIG 9). These synapses are of the en passant type, similar to those seen in the somatic neurons. The pharyngeal motor neurons also form neuromuscular junctions (NMJs) onto pharyngeal muscles. Interestingly, all non-neuronal cells receive some synaptic input (Cook et al., 2019). Unlike NMJs between somatic neurons and body wall muscles, no basal lamina has been found separating the neurons from muscles in the pharynx. There are no direct contacts between pharyngeal neurons and the larger somatic nervous system except the gap junctions made between RIPL/R neurons and the pharyngeal I1s, and gap junctions between RIPL/R and the pharyngeal motor neuron, M1 (Albertson and Thomson, 1976; Avery and Thomas, 1997). Ablation of RIP cells results in only a minor effect on pharyngeal function such that the brief inhibition of pumping in response to light touch to body disappears (Avery and Thomas, 1997). It is possible that one or more pharyngeal neurons, such as NSM cells, could secrete hormonal factors into the pseudocoelom to influence the rest of the animal. Otherwise, pharyngeal and somatic nervous systems function more or less independently of each other. A dissected and isolated pharynx continues its normal pumping behavior (Avery et al., 1995). In fact, generation of electrical potential changes required for pharyngeal pumping is probably intrinsic to the pharyngeal muscle cells themselves since pumping behavior continues even when all the pharyngeal neurons are ablated (Avery and Horvitz, 1989). Although pumping can still occur after complete ablation of the pharyngeal nervous system, four of the pharyngeal neurons, MC and M3 motor neuron pairs, are important for the regulation of the pump motion. Pharyngeal neurons fall into three categories: motorneurons, interneurons and other neurons. However, this distinction is somewhat arbitrary because most of these neurons have structures that suggest mixed functions. 7.1 Pharyngeal Motor Neurons Among motor neurons, M2 and M3 are paired neurons, whereas M1, M4 and M5 are single (PhaFIG 10; PharynxAtlas). M2 and M3 neurons are subventrally located and each innervates one side of the subventral and dorsal muscle sectors. M3s are also suggested to have proprioceptive sensory function. M4 and M5 neurons send out two branches, each of which first innervates the subventral sectors and then turns and innervates the dorsal sectors. 7.2 Interneurons I1, I2, I3 and I6 are unbranched bipolar cells. I1 cells make electrical synapses with the somatic neurons RIPL/R and synapse onto MC neurons. I5 is a fairly complex cell, the processes of which make a circle within the pharyngeal nerve ring. All of these neurons except for I4 have free subcuticular endings that may have proprioceptive function (Cook et al., 2019). See PharynxAtlas for more details. 7.3 Sensory Neurons Rudimentary sensory adaptions have been found in most pharyngeal neurons, although none form true cilia (Albertson and Thomson, 1976; Cook et al., 2020). These specializations mean that almost all neurons of the pharynx are truly polymodal. Most sensors are localized to prominent internal structures along the alimentary canal, probably helping to detect progress of food items (bacteria) as they proceed down the buccal channel towards the intestine (PhaFIG 11). Other sensors are embedded inside individual muscle cells and likely provide proprioceptive feedback by detecting muscle contractions during the feeding rhythm. PhaFIG 11: Sensory neuron endings in the pharynx. A&B Sensory endings are primarily associated with specific lumen structures within the pharynx. C&E The sensory endings are found on both neurons classically considered as interneurons such as I1 and motor neurons such as M5. Figure modified from Cook et al., 2020. Three “interneurons “ I1, I2 and I3 form sensory structures in close association to the flaps, at the entry point to the buccal channel, and some are exposed to the channel contents. The MC cell forms an unexposed sensory structure close to the sieve, while the NSM neurons each have an exposed sensory structure there (PhaFIG 11). The NSM ending expresses an Acid-Sensing Ion Channel (ASIC), DEL-7, at this structure. This channel may allow contents of the buccal channel to directly influence physiological activity of NSM (Axang et al., 2008; Rhoades et al, 2019). M3 and M4 neurons form exposed structures along the buccal channel near the isthmus. I6 and the M5 cell each have apparent sensory structures associated with the grinder. The I5 neuron has a sensory ending buried deep inside a muscle cell in the second bulb, providing a proprioceptive cue during bulb contractions. None of these pharyngeal sensors constitutes a true cilium, as they all lack features like an axoneme, Y-links or a microtubule-filled extension. Instead, these structures feature prominent adherens junctions that strongly link a short, block-like dendritic ending to the surrounding cells. Where the ending lies directly against the pharyngeal luminal cuticle it is referred to as an “exposed” ending (exposed to the lumen of the pharynx). If the ending lies somewhat away from the phayrnx’s internal cuticle, it is referred as an “unexposed” ending (if still close to the lumen) or a “buried” ending (if far from the lumen). These endings were originally listed in Table 1 in Albertson and Thomson (1976). 7.4 Pharyngeal Connectome The synaptic connectivity among the pharyngeal neurons and muscles is virtually independent of the somatic nervous system, except for a few contacts via the RIP neurons of the nerve ring. The complete set of synaptic connections (chemical and electrical) within the pharynx was substantially augmented by Cook et al., (2020). Many more synapses were added, and the previous wiring documented by Albertson and Thomson (1976) was verified. Virtually every cell in the pharynx of any type is now known to be included in this local circuitry. Re-analysis of the revised connectome has revealed how those circuits can be parsed into several distinct modules that match known stages in pharyngeal behavior: 1) pumping, 2) neuromodulation, 3) peristalsis, and 4) grinding (Cook et al., 2020) (PhaFIG 11). It is also interesting that the neuropeptides and receptors that interconnect the pharyngeal neurons appear to be somewhat separate from the peptidergic system of the somatic nervous system (see Figure 5 in Beets et al, 2023). There are exceptions: for instance the common FRPR-7 receptor proteins expressed in many pharyngeal neurons, are responsive to the FLP-1 ligand released by the AVK neurons of the nerve ring. Several classes of pharyngeal neurons also produce neuropeptide ligands that principally target somatic neurons (Beets et al, 2023). These peptidergic connections tend to operate at a distance, and do not require close contact, nor do they shadow the chemical and electrical wiring of the nervous system. 7.5 Other Neurons MC neurons are a pair of bipolar cells situated within the anterior bulb that make chemical synapses exclusively onto marginal cells (Cook et al., 2019). The motor-interneuron, MI, is a single unipolar cell situated in the dorsal side of the anterior bulb and synapses onto both muscle and other neurons. The neurosecretory-motor neurons NSML and NSMR send out branches that form varicosities and contain mixed-sized vesicles (PhaFIG 9). The two main processes of the NSMs run in close apposition to the pseudocoelom over most of their length and form some release sites towards this space. NSMs are serotonergic. These cells may have both neurosecretory and motor functions and may communicate the presence of food to the rest of the animal's body. Exogenous application of serotonin stimulates pumping, decreases locomotion and stimulates egg-laying (Horvitz et al., 1982). The same responses are seen in the presence of bacteria in the environment. NSMs were thought to be potential candidates for mediating the effects of endogenous serotonin. However, ablation of NSMs has only subtle effects on pumping, suggesting that they may be redundant for this function (Avery et al., 1993, Avery and Thomas, 1997). The slowing of locomotion in the presence of bacteria becomes more enhanced in animals that were previously food-deprived, compared to well-fed animals. This phenomenon is described as "the enhanced slowing response." When NSMs are ablated there is a small but significant decrease in this enhanced slowing of locomotion, which suggests NSMs contribute to this behavior (Sawin et al., 2000). 8 Pharyngeal-Intestinal Valve (VPI) A group of six equivalent interlocking cells links the posterior bulb of the pharynx to the anterior four cells of the intestine (PhaFIG 12, PhaFIG 13 and PhaMOVIE 4.) These six cells comprise a small epithelial channel with a cuticular lining in continuity with the pharyngeal cuticle. The channel links the lumen of the pharynx to the large lumen of the anterior intestine. Three sets of cells form consecutive rings containing one, three and two cells from anterior to posterior (PhaFIG 13). The inside cuticle is reinforced by a series of closely spaced circumferential ridges, rather like the cuticle of the anterior buccal cavity. The valve cells are not syncytial, but are firmly linked to their neighbors and to the pharynx and/or intestine by robust adherens junctions at their apical borders and by gap junctions (valve-to-valve cell and valve to intestine) (PhaFIG 12). PhaFIG 12: Pharyngeal-intestinal valve (vpi) is composed of six cells: one vpi1, three vpi2 and two vpi3. A. Horizontal TEM section through the pharynx-intestine junction. Each valve cell occupies a thin wedge-shaped domain surrounding some of the lumen of the valve. Bar, 1 μm. (Image source: Hall archive.) B. Adjacent thin section showing the valve cells in higher resolution. (Arrowhead) vpi1 projection into pm8, which is sealed to pm8 by adherens junctions. Bar, 1 μm.(Image source: Hall archive.) C. Epifluorescent image of the valve expressing the reporter gene hum-1::GFP, lateral view. (Strain source: M. Titus.) Magnification, 400x. PhaFIG 13: Structure of the pharyngeal valve. Shown is stacking of the six vpi cells from the anterior end (top left) toward the posterior. Three-dimensional rendition of the cells based on tracings from serial TEMs. (Image source: B. Henick and A Hartley, based on MRC series.) Each cell is given a unique color. Colors do not follow the WormAtlas color code. PhaMOVIE 4: 3-D reconstruction of how VPI cells stack. Stacking of the six vpi cells from the anterior end (top left) toward the posterior is shown. Three-dimensional rendition of the cells based on tracings from serial TEMs. (Image source: B. Henick and A Hartley, based on MRC series.) Each cell is given a unique color. Colors do not follow the WormAtlas color code. Click on image to play movie. No apparent muscular elements operate within the valve cells, nor are there any muscles attaching to this valve from the outside. Thus, the valve is probably a passively open and patent channel at all times, but rather narrow in caliber. The pm8 muscle of the pharynx is in appropriate position to act alone as a sphincter just rostral to the valve cells, but pm8 shows no direct innervation (Albertson and Thomson, 1976; Cook et al., 2019). Contraction of the pm8 has been suggested to open the valve wider when the grinder is active (Avery and Thomas, 1997). Each valve cell has an electron-dense cytoplasm and occupies a thin wedge-shaped domain surrounding about one half of the lumen of the valve (PhaFIG 12). The nuclei of valve cells are flattened in shape, and the cytoplasm contains radial bands of intermediate filaments anchoring the apical cuticle to the basal lamina of the epithelium via hemidesmosomes, again in a very similar fashion to those seen in the buccal epithelium (D.H. Hall, unpublished). 9 Specific Structures Within the Pharynx 9.1 Channels of the Pharyngeal Lumen Radial channels, three narrow grooves in outer corners of the pharyngeal cuticle, are located in both the anterior procorpus and anterior isthmus (PhaFIG 2) (Albertson and Thomson, 1976). The channels allow an escape route for liquid to be regurgitated out of the pharynx via the buccal cavity. This results in food particles being trapped in the central lumen while fluid is expelled through the channels (Fang-Yen et al., 2009). 9.2 Cuticle of the Pharynx A thin cuticle lining extends to cover the interior surface of the pharyngeal passageway from the lips to the back of the pharynx, ending at the rear of the pharyngeal-intestinal valve (PhaFIG 2). The pharyngeal cuticle is formed by the pharyngeal epithelium and the muscle cells to cover the apical surfaces of many cells acting in concert, much as the thickened pharyngeal basal lamina is formed jointly on basal surfaces of the pharyngeal cells. Unlike the body cuticle (see Hermaphordite Cuticle), this cuticle shows no layers; however, it shows some reinforcement at points of stress. For instance, it becomes keratinized to stain more densely by TEM at certain regions. Other specialized portions of the pharyngeal cuticle include the following. 9.2.1 Bridging Cuticle A small discrete region of cuticle connects the body wall cuticle covering the lips to the cuticle lining the buccal cavity. This bridging cuticle lies on the outer face of the anterior arcade and may also be touched briefly by the posterior arcade (see Epithelial System - Interfacial Cells; InterFIG 1). 9.2.2 Flaps The metastomal flaps are cuticular projections at the base of the buccal cavity and may correspond to the onchia or buccal teeth described in other nematode species (Chitwood and Chitwood, 1950; Theska and Sommer, 2023; see also PhaFIG 2; PhaFIG 5; InterFIG 1). Three flaps extend inward from the level of from the pharyngeal muscle cells pm1 and pm2 to restrict the intake rate of bacteria at the rear of the buccal cavity (Fang-Yen et al., 2009). The flap cuticle is very electron dense, suggesting a sclerotic hardening to stiffen the flaps and the entryway to the true pharynx. 9.2.3 Grinder The grinder (PhaFIG 2) is a cuticle specialization with five distinct layers (Sparacio et al., 2020). Its three contact zones, made by the three pairs of muscle cells, rotate when the muscles contract (Avery and Thomas, 1997). The food caught and ground up between the teeth is passed back to the intestine through the pharyngeal-intestinal valve. Relaxation of the terminal bulb returns the grinder to its resting state. The grinder is made primarily by pm6 and pm7 muscles, which produce large quantities of secretory vesicles during periods of lethargus when the grinder is rebuilt (Sparacio et al., 2020). During the initial breakdown, pm6 and pm7 vesicles have an electron dense appearance, whereas later during the reformation of the new grinder most vesicles have an electronlucent appearance suggesting distinct enzymes for the absorption and building of the grinder structure. Its three contact zones, made by the three pairs of muscle cells, rotate when the muscles contract (Avery and Thomas, 1997). Although the pm6 muscle filaments are oriented in radial fashion to the grinder, some portions of the pm7 muscles are oriented obliquely to the anterior-posterior axis and are anchored on the basal pole to the rear of the terminal bulb. During lethargus, the muscle striations appear to be interrupted suggesting a temporary differentiation from a muscular to a secretory cell type. The pm6 and pm7 muscle fibers pull from the posterior side of the teeth, and coordinated action of these muscles may then rotate the grinder segments and force the teeth to scrape past and engage one another. 9.2.4 Pharyngeal Sieve These finger-like extensions from the pharyngeal cuticle probably act to trap bacteria, just posterior of the metacorpus (Fang-Yen et al., 2009; PhaFIG 2). They extend from the cell borders where pm4 muscles meet the neighboring mc1 cells. They project over a region of about 20 μm in length within the narrow lumen, ending near the transition of the metacorpus to the isthmus. 9.3 Gap Junctions (see also chapter on Gap Junctions) The muscle cells and the marginal cells of the pharynx are linked to and communicate with each other via elaborate gap junctions (Phelan, 2005; Altun et al., 2009; Bhattacharya et al., 2019; see also PhaFIG 7; PhaTABLE 1). Gap junctions also exist between the pharyngeal neurons and also between the pharyngeal neuron I1 and the extrapharyngeal neuron RIP. Gap junctions within the pharynx are composed of innexins, invertebrate gap junction proteins. Innexins heteromerically assemble into hexameric hemichannels and form pores between cells. This gap junction network confers a high level of connectivity within the pharynx, which is essential in coordinating waves of muscle contractions and spreading the neuronal input. 10 Feeding Behavior C. elegans is a filter-feeder. Particles (bacteria) are taken in as suspended in liquid and then trapped in the pharynx while the liquid is expelled outside by the function of the corpus and anterior isthmus (Avery and Thomas, 1997; Avery and Shtonda, 2003). The particles are then transported to the terminal bulb, ground and passed into the lumen of the intestine. The feeding behavior consists of two motions; pumping, a contraction-relaxation cycle involving the corpus, anterior half of the isthmus and terminal bulb; and posterior isthmus peristalsis. Pumping involves near-simultaneous contraction of the muscles of the corpus, anterior isthmus and terminal bulb followed by near-simultaneous relaxation. When a feeding motion begins, contraction of the corpus and anterior isthmus opens their lumens, sucking particles and liquid in, whereas contraction of the terminal bulb muscles breaks up already-trapped bacteria and passes the debris posteriorly towards the intestine (Avery and Shtonda, 2003). At this stage corpus and anterior isthmus are separated hydrodynamically from the terminal bulb by a closed isthmus. During the relaxation period that follows, the lumens of the corpus and the anterior isthmus close, allowing for the liquid to be expelled through the radial channels while bacteria are retained and the grinder returns to its resting position (Fang-Yen et al., 2009). Food particles are trapped at two locations: the anterior procorpus and anterior isthmus. At each location, early relaxation of the pharyngeal lumen just anterior to the trap location prevents particles from exiting the trap (Fang-Yen et al., 2009). When the muscles again contract, the bacteria are carried further posteriorly by the inflow of liquid. Roughly one out of four pumps is followed by a posterior isthmus peristalsis where the trapped bacteria are carried from the anterior isthmus backwards to the grinder. Although each pm5 muscle cell runs the entire length of the isthmus, peristalsis occurs as a wave that propagates from anterior to posterior instead of simultaneously along its length. This capacity of isthmus for asynchronous contraction is suggested to permit the terminal bulb and corpus lumen to be at different pressures (Avery and Thomas, 1997). Neural control of feeding has been elucidated through both neuronal ablation and optogenetic manipulation of neuron activity (Avery and Horvitz, 1989; Trojanowski et al., 2014). Interestingly, pumping continues even after ablation of all pharyngeal neurons, albeit at a highly reduced rate (Avery and Horvitz, 1989). However, elimination of cholinergic signaling leads to a complete loss of pumping (Avery and Horvitz, 1990; Alfonso et al., 1993). Isthmus peristalsis is controlled by M4. Ablation of M4, which innervates the isthmus and terminal bulb muscles, leads to faulty isthmus peristalsis and a “stuffed” worm appearance where food remains stuck in the isthmus, eventually leading to starvation (Avery and Horvitz, 1989). M4 also plays a minor role in pumping with optogenetic excitation of M4 leading to an increase in the pumping rate. Conversely, optogenetic inhibition or ablation of M4 causes a decrease in the pumping rate (Raizen et al., 1995; Trojanowski et al., 2014). The rate of pumping is controlled by the MC, M2, and M4 motor neurons (Avery and Horvitz, 1989; Trojanowski et al., 2014). The I1 neurons, which make the only connection to the somatic nervous system, regulate pumping via the MC and M2 neurons. The MC, M2 and M4 neurons are cholinergic excitatory motor neurons (Raizen et al., 1995; Keane and Avery, 2003). Mutants in which acetylcholine synthesis (cha-1) or packaging (unc-17) is disrupted show a pumping defect similar to that seen after MC ablation. Functional studies suggest that MC neurons synapse onto pm4 and that synaptic transmission from MC neurons to pm4 requires the nicotinic acetyl-choline receptor (nAChR) subunit, EAT-2 to be expressed on pm4. MC neurons may also be mechanosensory, because they have free endings at the boundary between the procorpus and metacorpus and may sense the presence of bacteria in the pharynx. Pumping is suppressed during dauer, lethargus, and in response to a touch stimulus in adults. As described above, the latter response depends on an RIP/I1 connection. This circuit may also be important for suppression of pumping in the dauer larva (Keane and Avery, 2003). Inhibition of pumping during the dauer stage may save energy and prevent ingestion of environmental toxins when no appropriate food is available. Feeding behavior is also impacted by exposure to light (Bhatla and Horvitz, 2015; Bhatla et al., 2015). Following exposure to light, feeding is inhibited and a subsequent reversal of flow in the pharynx leads to expulsion of bubbles (“spitting”) from the mouth. Light-induced inhibition of feeding acts through both the I2 neurons and the RIP/I1 connection. The I2 neurons, which were originally classified as interneurons, also synapse directly onto pharyngeal muscle (Bhatla et al., 2015; Cook et al., 2019). Spitting behavior is controlled by M1, which may continuously contract the pm3 muscles allowing for pharyngeal contents to escape during the reduced pumping. 11 List of Pharyngeal Cells i. Buccal epithelium of the pharynx (e) 1. First epithelial ring e1D e1VL e1VR 2. Second epithelial ring e2DL e2DR e2V 3. Third epithelial ring e3D e3VL e3VR ii. Pharyngeal muscles (pm). Note that in earlier publications these cells are labeled as "m"; m1, m2, m3 etc., but here they are labeled "pm" for "pharyngeal muscle" (Avery and Thomas, 1997). 1. First pharyngeal muscle ring; all fuse into one syncytium around hatching pm1DL pm1DR pm1L pm1R pm1VL pm1VR 2. Second pharyngeal muscle ring pm2DL; fuses with DR around hatching pm2DR; fuses with DL around hatching pm2L; fuses with VL around hatching pm2R; fuses with VR around hatching pm2VL; fuses with L around hatching pm2VR; fuses with R around hatching 3. Third pharyngeal muscle ring pm3DL; fuses with DR around hatching pm3DR; fuses with DL around hatching pm3L; fuses with VL around hatching pm3R; fuses with VR around hatching pm3VL; fuses with L around hatching pm3VR; fuses with R around hatching 4. Fourth pharyngeal muscle ring; all fuse into one syncytium around hatching pm4DL; pm4DR; pm4L; pm4R; pm4VL; pm4VR; 5.Fifth pharyngeal muscle ring; all fuse into one syncytium around hatching pm5DL; pm5DR; pm5L; pm5R; pm5VL; pm5VR; 6. Sixth pharyngeal muscle ring pm6D pm6VL pm6VR 7. Seventh pharyngeal muscle ring pm7D pm7VL pm7VR 8. Eighth pharyngeal muscle ring pm8 iii. Marginal cells (mc) 1. First marginal cell ring mc1DL mc1DR mc1V 2. Second marginal cell ring mc2DL mc2DR mc2V 3. Third marginal cell ring (syncytial, cells fuse around hatching) mc3DL mc3DR mc3V iv. Pharyngeal-intestinal valve (vpi) 1. First pharyngeal valve ring vpi1 2. Second pharyngeal valve ring vpi2DL vpi2DR vpi2V 3. Third pharyngeal valve ring vpi3D vpi3V v. Pharyngeal neurons 1. Motor neurons M1 M2L/R M3L/R M4 M5 2. Interneurons I1L/R I2L/R I3 I4 I5 I6 2. Other neurons MI NSML/R MCL/R vi. Pharyngeal glands (g) 1. First pharyngeal gland ring g1AL; ventral left g1 gland cell g1AR; ventral right g1 gland cell g1P; dorsal gland cell 2. Second pharyngeal gland ring g2L g2R See also PharynxAtlas 12 References Albertson, D.G. and Thomson, J.N. 1976. The pharynx of Caenorhabditis elegans. Phil. Trans. Royal Soc. London 275B: 299-325. doi: 10.1098/rstb.1976.0085 Article-html Altun, Z.F., Chen, B., Wang, Z-W. and Hall, D.H. 2009. High resolution map of Caenorhabditis elegans gap junction proteins. Dev. Dyn. 238:1936-1950. doi: 10.1002/dvdy.22025 Avery, L. Bargmann, C.I. and Horvitz, H.R. 1993. The Caenorhabditis elegans unc-31 gene affects multiple nervous system-controlled functions. Genetics 134: 454-464. doi: 10.1093/genetics/134.2.455 Avery, L. and Horvitz, H R. 1987. A cell that dies during wild-type C. elegans development can function as a neuron in a ced-3 mutant. Cell 51: 1071-1078. doi: 10.1016/0092-8674(87)90593-9 Avery, L. and Horvitz, H.R. 1989. Pharyngeal pumping continues after laser killing of the pharyngeal nervous system of C. elegans. Neuron 3: 473-485. doi: 10.1016/0896-6273(89)90206-7 Avery, L., Lockery, S. and Raizen, D.M. 1995. Electrophysiological methods in C. elegans. In: Epstein, H.F. and Shakes D.C., editors. Caenorhabditis elegans: Modern biological analysis of an organism. New York: Academic Press. 251-269. Article Avery, L. and Shtonda, B.B. 2003. Food transport in the C. elegans pharynx. J. Exp. Biol. 206: 2441-2457. doi: 10.1242/jeb.00433 Avery, L. and Thomas, J.H. 1997. Feeding and defecation. In C. elegans Volume II. Ed.s Riddle D.L., Blumenthal, T., Meyer B.J. and Priess J.R . Pp 679-716. Cold Spring Harbor Laboratory Press. Article Axang, C., Rauthen, M., Hall, D.H. and Pilon, M. 2008. Developmental genetics of C. elegans pharyngeal neurons NSML and NSMR. BMC Dev. Bio. 8: 38. doi:10.1186/1471-213X-8-38 Beets, I., Zels, S., Vandewyer, E., Demeulemeester, J., Caers, J., Baytemur, E., Courtney, A., Golinelli, L., Hasakiogullan, I., Schafer, W.R., Vertes, P.E., Mirabeau, O. and Schoofs, L. 2023. System-wide mapping of peptide-GPCR interactions in C. elegans. Cell Rep. 42: 113058. doi: 10.1016/j.celrep.2023.113058 Bhatla, N., Droste, R., Sando, S.R., Huang, A. and Horvitz, H.R. 2015. Distinct neural circuits control rhythm inhibition and spitting by the myogenic pharynx of C. elegans. Curr. Bio. 25: 2075-2089. doi: 10.1016/j.cub.2015.06.052 Bhatla, N. and Horvitz, H.R. 2015. Light and hydrogen peroxide inhibit C. elegans feeding through gustatory receptor orthologs and pharyngeal neurons. Neuron 85: 804-818. doi: 10.1016/j.neuron.2014.12.061 Bhattacharya, A., Aghayeva, U., Berghoff, E.G. and Hobert, O. 2019. Plasticity of the electrical connectome of C. elegans. Cell 176: 1174-1189. doi: 10.1016/j.cell.2018.12.024 Bird, A.F. and Bird, J. 1991. The structure of nematodes. Academic Press, San Diego, CA. doi: 10.1016/C2009-0-02659-2 Bucher, E.A. and Seydoux, G.C. 1994. Gastrulation in the nematode Caenorhabditis elegans. Seminars in Developmental Biology. 5: 121-130. doi: 10.1006/sedb.1994.1016 Chalfie, M., Sulston, J.E., White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1985. The neural circuit for touch sensitivity in Caenorhabditis elegans. J. Neurosci. 5: 956-964. doi: 10.1523/JNEUROSCI.05-04-00956.1985 Chitwood, B.G. and Chitwood, M.B. 1950. An introduction to nematology. Baltimore, University Park Press. Book Cook, S.J., Jarrell, T.A., Brittin, C.A., Wang, Y., Bloniarz, A.E., Yakovlev, M.A., Nguyen, K.C.Q., Tang, L.T., Bayer, E.A., Duerr, J.S., Blow, H.E., Hobert, O., Hall, D.H. and Emmons, S.W. 2019. Whole-animal connectomes of both Caenorhabditis elegans sexes. Nature 571: 63-71. doi: 10.1038/s41586-019-1352-7 Cook, S.J., Crouse,, C.M., Yemini, E., Hall, D.H., Emmons, S.W. and Hobert, O. 2020. The connectome of the Caenorhabditis elegans pharynx. J. Comp. Neur. 528: 2767-2784. doi: 10.1002/cne.24932 Dent, J.A., Davis, M.W. and Avery, L. 1997. avr-15 encodes a chloride channel subunit that mediates inhibitory glutamatergic neurotransmission and ivermectin sensitivity in Caenorhabditis elegans. EMBO Journal 16: 5867-5879. doi: 10.1093/emboj/16.19.5867 Dent, J.A., Smith, M.M., Vassilatis, D.K. and Avery, L. 2000. The genetics of ivermectin resistance in Caenorhabditis elegans. Proc. Natl. Acad. Sci. USA 97: 2674-2679. doi: 10.1073/pnas.97.6.2674 Fang-Yen, C., Avery, L. and Samuel, S.D.T. 2009. Two size-selective mechanisms specifically trap bacteria-sized food particles in Caenorhabditis elegans. Proc. Natl. Acad. Sci. USA 106: 20093-20096. doi: 10.1073/pnas.0904036106 Franks, C.J., Holden-Dye, L., Bull, K., Luedtke, S. and Walker, R.J. 2006. Anatomy, physiology and pharmacology of Caenorhabditis elegans pharynx: a model to define gene function in a simple neural system. Invert. Neurosci. 6: 105-122. doi: 10.1007/s10158-006-0023-1 Hall, D.H. and Hedgecock, E.M. 1991. Kinesin-related gene unc-104 is required for axonal transport of synaptic vesicles in C. elegans. Cell 65: 837-847. doi: 10.1016/0092-8674(91)90391-b Harry, C.J., Messar, S.M. and Ragsdale E.J. 2022. Comparative reconstruction of the predatory feeding structures of the polyphenic nematode Pristionchus pacificus. Evo. Dev. 24:16-36. doi: 10.1111/ede.12397 Hedgecock, E.M. and Thomson, J.N. 1982. A gene required for nuclear and mitochondrial attachment in the nematode C. elegans. Cell 30: 321-330. doi: 10.1016/0092-8674(82)90038-1 Horner, M.A., Quintin, S., Domeier M.E., Kimble, J.E., Labouesse, M. and Mango, S.E. 1998. pha-4, an HNF-3 homolog, specifies pharyngeal organ identity in Caenorhabditis elegans. Genes Dev. 12: 1947-1952. doi: 10.1101/gad.12.13.1947 Horvitz, H.R., Chalfie, M., Trent, C., Sulston, J.E. and Evans, P.D. 1982. Serotonin and octopamine in the nematode Caenorhabditis elegans. Science 216:1012-1014. doi: 10.1126/science.6805073 Keane, J. and Avery, L. 2003. Mechanosensory inputs influence Caenorhabditis elegans pharyngeal activity via ivermectin sensitivity genes. Genetics 164: 153-162. doi: 10.1093/genetics/164.1.153 Knight, C.G., Patel, M.N., Azevedo, R.B.R. and Leroi, A.M. 2002. A novel mode of ecdysozoan growth in Caenorhabditis. Evol. Dev. 4: 16-27. doi: 10.1046/j.1525-142x.2002.01058.x Koppen, M., Simske, J.S., Sims, P.A., Firestein, B.L., Hall, D.H., Radice, A.D., Rongo, C. and Hardin, J.D. 2001. Cooperative regulation of AJM-1 controls junctional integrity in Caenorhabditis elegans epithelia. Nature Cell Biol. 3: 983-991. doi: 10.1038/ncb1101-983 Leung, B., Hermann, G.J and Priess, J.R. 1999. Organogenesis of the Caenorhabditis elegans intestine. Dev. Biol. 216: 114-134. doi: 10.1006/dbio.1999.9471 Mango, S.E. 2007. The C. elegans pharynx: a model for organogenesis. WormBook, ed. The C. elegans Research Community, WormBook, doi: 10.1895/wormbook.1.129.1 McCloskey, R.J., Fouad, A.D., Churgin, M.A. and Fang-Yen, C. 2017. Food responsiveness regulates episodic behavioral states in Caenorhabditis elegans. J. Neurophysiol. 117: 1911-1934. doi: 10.1152/jn.00555.2016 Phelan, P. 2005. Innexins: members of an evolutionarily conserved family of gap-junction proteins. Biochim. Biophys. Acta 1711: 225-245. doi: 10.1016/j.bbamem.2004.10.004 Portereiko, M.F. and Mango, S.E. 2001. Early morphogenesis of the Caenorhabditis elegans pharynx. Dev. Biol. 233: 482-494. doi: 10.1006/dbio.2001.0235 Rasmussen, J.P., English, K., Tenlen, J.R. and Priess, J.R. 2008. Notch signaling and morphogenesis of single-cell tubes in the C. elegans digestive tract. Dev. Cell 14: 559-569. doi: 10.1016/j.devcel.2008.01.019 Rasmussen, J.P., Feldman, J.L., Somashekar, S. and Priess, J.R. 2013. Cell interactions and patterned intercalations shape and link epithelial tubes in Caenorhabditis elegans. PLoS Genetics 9: e1003772. doi: 10.1371/journal.pgen.1003772 Raharjo, W.H., Ghai, V., Bastiani, M. and Gaudet, J. 2011. Cell architecture: surrounding muscle cells shape gland cell morphology in Caenorhabditis elegans pharynx. Genetics 189: 885-897. doi: 10.1534/genetics.111.132449 Raizen, D.M., Lee, R.Y.N. and Avery, L. 1995. Interacting genes required for pharyngeal excitation by motor neuron MC in Caenorhabditis elegans. Genetics 141: 1365-1382. doi: 10.1093/genetics/141.4.1365 Rhoades, J.L., Nelson, J.C., Nwabudike, I., Yu, S.K., McLachlan, I.G., Madan, G.K., Abebe, E., Powers, J.R., Colon-Ramos, D.A. and Flavell, S.W. 2019. ASICs mediate food responses in an enteric serotonergic neuron that controls foraging behaviors. Cell 176: 85-97. doi: 10.1016/j.cell.2018.11.023 Sando, S.R., Bhatla, N., Lee, E.L.Q. and Horvitz, H.R. 2021. An hourglass circuit motif transforms a motor program via subcellularly localized muscle calcium signaling and contraction. eLife 10: e59341. doi: 10.7554/eLife.59341 Singh, R.N. and Sulston, J.E. 1978. Some observations on moulting in Caenorhabditis elegans. Nematologica 24: 63-71. Article Smit, R. B., Schnabel, R. and Gaudet, J. 2008. The HLH-6 transcription factor regulates C. elegans pharyngeal gland development and function. PLoS Genetics 4: e1000222. doi: 10.1371/journal.pgen.1000222 Sparacio, A.P., Trojanowski, N.F., Snetselaar, K., Nelson, M.D. and Raizen, D.M. 2020. Teething during sleep: Ultrastructural analysis of pharyngeal muscle and cuticular grinder during the molt in Caenorhabditis elegans. PLoS ONE. 15:e0233059. doi: 10.1371/journal.pone.0233059 Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. (html) doi: 10.1016/0012-1606(83)90201-4 Theska, T. and Sommer, R.J. 2023. Feeding-structure morphogenesis in "rhabditid" and diplogastrid nematodes is not controlled by a conserved genetic module. Evo. Dev. 26: e12471. doi: 10.1111/ede.12471 Trojanowski, N.F., Padovan-Merhar, O., Raizen, D.M. and Fang-Yen, C. 2014. Neural and genetic degeneracy underlies Caenorhabditis elegans feeding behavior. J. Neurophys. 12: 951-6\961. doi: 10.1152/jn.00150.2014 Wright, K.A. and Thomson, J.N. 1981. The buccal capsule of C. elegans (Nematoda: Rhabditoidea): An ultrastructural study. Can. J. Zool. 59: 1952-1961. (html) doi: 10.1139/z81-266
This chapter should be cited as: Schroeder, N.E., Altun, Z.F. and Hall, D.H. 2024. Alimentary System, Pharynx. In WormAtlas. doi:10.3908/wormatlas.1.3 We would like to thank Christopher Fang-Yen for providing feedback on this chapter. Edited for the web by Nathan E. Schroeder and Laura A. Herndon. Last revision: November 7th, 2024.

©Copyright 2024 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |